===============
Django Auxilium
===============

Contents
========

.. toctree::
   :maxdepth: 2

   highlights
   history
   api/modules

.. include:: ../README.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
